Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: ash/common/wm/wm_event.h

Issue 2700523004: Remove docked windows entirely in M59. (Closed)
Patch Set: Rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm/window_state_observer.h ('k') | ash/common/wm/wm_types.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/wm_event.h
diff --git a/ash/common/wm/wm_event.h b/ash/common/wm/wm_event.h
index e26ba78d46a83d1b66ef46185323a2a90b672cfa..4e0d49c22643ef7a68763c9e90b97894285db864 100644
--- a/ash/common/wm/wm_event.h
+++ b/ash/common/wm/wm_event.h
@@ -27,7 +27,6 @@ enum WMEventType {
WM_EVENT_FULLSCREEN,
WM_EVENT_SNAP_LEFT,
WM_EVENT_SNAP_RIGHT,
- WM_EVENT_DOCK,
// A window is requested to be the given bounds. The request may or
// may not be fulfilled depending on the requested bounds and window's
@@ -55,18 +54,17 @@ enum WMEventType {
// A user requested to toggle fullscreen state.
WM_EVENT_TOGGLE_FULLSCREEN,
- // A user requested a cycle of dock and snap left.
+ // A user requested a cycle of snap left.
// The way this event is processed is the current window state is used as
// the starting state. Assuming normal window start state; if the window can
- // be snapped left, snap it; otherwise progress to next state. If the window
- // can be docked left, dock it; otherwise progress to next state. If the
+ // be snapped left, snap it; otherwise progress to next state. If the
// window can be restored; and this isn't the entry condition restore it;
// otherwise apply the bounce animation to the window.
- WM_EVENT_CYCLE_SNAP_DOCK_LEFT,
+ WM_EVENT_CYCLE_SNAP_LEFT,
- // A user requested a cycle of dock and snap right.
- // See decription of WM_EVENT_CYCLE_SNAP_DOCK_LEFT.
- WM_EVENT_CYCLE_SNAP_DOCK_RIGHT,
+ // A user requested a cycle of snap right.
+ // See decription of WM_EVENT_CYCLE_SNAP_LEFT.
+ WM_EVENT_CYCLE_SNAP_RIGHT,
// A user requested to center a window.
WM_EVENT_CENTER,
« no previous file with comments | « ash/common/wm/window_state_observer.h ('k') | ash/common/wm/wm_types.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698